#!/bin/sh

# Build script for MUMmer
# Author: Ejis <ejis at mailoo.org>

# Homepage: http://mummer.sourceforge.net/


# Stop when an error occurs.

set -e


# These variables set the name of the package, its version,
# which Zenwalk version it's built for and the number of this
# build for this version.

SOFTNAME=mummer
DLNAME=MUMmer
VERSION=3.23
ZENVER=72
BUILD=1

# Zenwalk category of the package (e.g.: extra/xap)

CATEGORY=extra/l

# The architecture this package is built for. It will be mostly
# i486, but when the package won't run right on i486, this value
# can be i686.
# This determines the flags to use during compile.

MARCH=i486
FLAGS="-O2 -march=$MARCH -mtune=i686"

# The DOTNEW variable tells the buildscript if it should convert
# every file in /etc to .new files, preventing previously
# installed files to be erased after an upgrade.
# The DOINST variable tells the buildscript to create a
# doinst.sh file, that contains post-install commands.

DOTNEW=1
DOINST=0

# Current directory.

CWD=$(pwd)

# Name of the package file before the extension.

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

# Source directory and the directory where the package will be
# installed before compression.

SOFTDIR=$CWD/${DLNAME}$VERSION
PKGDIR=$CWD/$PKG

# Files created by the script.
# The .txz file is the package file, the .md5 is its md5sum, the
# .src file is the file that contains the URLs where to download
# the files used for building and the .dep file is the list of
# the dependencies.

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep

# Files needed to make the package. Most of the time, it will
# only be the source tarball, but sometimes, some extra files
# are needed, like patches or icon images.
# Some files are kept in /usr/src. The buildscript is
# mandatory but some of the source files can also be added if
# they are small files.

SRCFILES=(
	${DLNAME}$VERSION.tar.gz
)
KEPTSRC=(
	$CWD/build-$SOFTNAME.sh
)

# The host url is the url where you will be able to find the
# package files.
# The source URLs are the URLs where the source files can be
# found. Sometimes, it can be the host URL.

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
	http://downloads.sourceforge.net/project/mummer/mummer/$VERSION
)

# When the source files and URLs are set, the complete links
# to them must be set.

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
)

# These files will be put in /usr/doc. These are mostly the text
# files you find in the source directory.

DOC=(
	$SOFTDIR/ACKNOWLEDGEMENTS
	$SOFTDIR/COPYRIGHT
	$SOFTDIR/ChangeLog
	$SOFTDIR/INSTALL
	$SOFTDIR/LICENSE
	$SOFTDIR/README
)

# Sometimes, some dependencies can't be found, so they must be
# named in order to be added to the .dep file.
# On the other hand, some dependencies can be wrong or
# unnecessary, so they should be removed from the .dep file.

EXTRADEPS=(
)

LESSDEPS=(
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi


# Erase the previous build files

rm -rf $PKGFILE $SOFTDIR $PKGDIR $MD5 $SRC $DEP
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

sed -i "s:-O3:-O2 -march=i486 -mtune=i686:g" Makefile

make -j2 || return 1
make install DESTDIR=$PKGDIR


mkdir -p $PKGDIR/usr/doc/$PKGNAME-$VERSION
mkdir -p $PKGDIR/usr/share/mummer
mkdir $PKGDIR/usr/lib
mkdir $PKGDIR/usr/bin

mv ./docs/* $PKGDIR/usr/doc/$PKGNAME-$VERSION/
mv ./scripts/* $PKGDIR/usr/share/mummer/

mv ./src/kurtz/libbasedir/*.a $PKGDIR/usr/lib/
mv ./src/kurtz/streesrc/*.a $PKGDIR/usr/lib/

mv ./exact-tandems \
	./run-mummer1 \
	./run-mummer3 \
	./annotate \
	./combineMUMs \
	./delta-filter \
	./gaps \
	./mgaps \
	./mummer \
	./repeat-match \
	./show-aligns \
	./show-coords \
	./show-diff \
	./show-snps \
	./show-tiling \
	./dnadiff \
	./mapview \
	./mummerplot \
	./nucmer \
	./nucmer2xfig \
	./promer \
		$PKGDIR/usr/bin/


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	       #|-----handy-ruler------------------------------------------------------|
cat << EOF > $PKGDIR/install/slack-desc
$SOFTNAME: $SOFTNAME
$SOFTNAME:
$SOFTNAME: MUMmer is a modular system for the rapid whole genome alignment of
$SOFTNAME: finished or draft sequence. This package provides an efficient suffix
$SOFTNAME: tree library, seed-and-extend alignment, SNP detection, repeat
$SOFTNAME: detection, and visualization tools.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

if [ $DOINST == 1 ]; then
	cat << EOF >> $PKGDIR/install/doinst.sh

EOF
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v ${KEPTSRC[@]} $PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKGDIR
